using PyCall
using Printf

cv2=pyimport("cv2")

#创建人脸检测器和识别器
names = ("None", "Spider Man", "Iron Man")
file = "lbpcascade_frontalface_improved.xml"
face_cascade = cv2.CascadeClassifier(file)
recognizer = cv2.face.LBPHFaceRecognizer_create()
recognizer.read("trainner.yml")

#读取测试的人脸图像
test_img = cv2.imread("testing/test1.jpg")
gray_img = cv2.cvtColor(test_img, cv2.COLOR_BGR2GRAY)
faces = face_cascade.detectMultiScale(gray_img, 1.2, 5)

#Julia数组是列主数组，而cv需要行主数组。
#反转维度，然后使用PyReverseDims数组
rimg = permutedims(test_img, ndims(test_img):-1:1)
pyimg = PyReverseDims(rimg)

#对检测出的每一个人脸图像进行测试
for i in 1:size(faces,1)
    (x,y,w,h)=faces[i,:]
    face = gray_img[y:y+w, x:x+h]
    face = cv2.resize(face, (256, 256))
    #使用人脸识别器预测图像
    label, confidence = recognizer.predict(face)
    confidence = 100 - confidence
    #取最大值
    if label > 0 && confidence > 50 
        cv2.rectangle(pyimg, (x, y), (x+w, y+h), (255, 0, 0), 2)
        text =@sprintf("%s:%d", names[label], confidence)
        print(text)
        font = cv2.FONT_HERSHEY_PLAIN
        cv2.putText(pyimg, text, (x, y), font, 2.5, (0, 255, 0), 2)
    end
end
#显示图像并等待
cv2.namedWindow("Image", cv2.WINDOW_NORMAL)
cv2.imshow("Image", pyimg)
cv2.waitKey(0)
cv2.destroyAllWindows()